\author{Hao Wu \email{hao@jax.org} }

\name{Rmaanova.version}
\alias{Rmaanova.version}

\title{Display the current version of the package}

\usage{
Rmaanova.version()
}

\description{
  This is the function to display the current verion number of R/maanova
  pakcage.}

\examples{
Rmaanova.version()
}

\keyword{utilities}

\eof
\name{abf1.raw}
\alias{abf1.raw}
\alias{abf1}
\docType{data}
\title{Data for a 18-array affymetrix experiment}
\description{
  This is the data set for a 18-array affymetrix experiment. There are
  three mouse strains, AJ, B6 and their F1 offspring. Three biological
  replicates each and two technical replicates for each individual.
}

\usage{data(abf1.raw)}

\format{
  An object of class \code{rawdata}.
}

\examples{
data(abf1.raw)
}

\keyword{datasets}

\eof
\author{Hao Wu \email{hao@jax.org} }

\name{adjPval}
\alias{adjPval}

\title{Generate FDR adjusted P values for F test result.}

\description{
  This function takes a result object from \code{\link[maanova]{matest}}
  and calcualte the FDR adjusted P values. The new P values will be
  appended to the input object as additional fields.
}

\usage{
adjPval(matestobj, method=c("stepup","adaptive", "stepdown"))
}

\arguments{
  \item{matestobj}{An object of class \code{matest}, which is the result
    from \code{\link[maanova]{matest}}.}
  \item{method}{The method for FDR control.}
}

\value{
  An object of class \code{matest} with the following fields added for
  each F test:
  \item{adjPtab}{FDR adjusted tabulated P values.}
  \item{adjPvalperm}{FDR adjusted permutation P values.}
}

\examples{
data(paigen)
paigen <- createData(paigen.raw, n.rep=2)
model.noint.fix <- makeModel(data=paigen, formula=~Array+Dye+Spot+Strain+Diet)
# F-test strain effect
\dontrun{test.strain.fix <- matest(paigen, model.noint.fix, term="Strain", n.perm=100,
        shuffle.method="resid", test.method=rep(1,4))
# make FDR adjusted P values
test.strain.fix <- adjPval(test.strain.fix)}
# there will be new fields in test.strain.fix after this
}

\keyword{utilities}

\eof
\author{Hao Wu \email{hao@jax.org} }

\name{arrayview}
\alias{arrayview}

\title{View the layout of input data}

\description{
  This function reconstructs the input data according to the micro array
  grid location structure and plots the data according to the user
  specified color map.

  Dy default, it will plot the log ratios for 2-dye array and raw
  intensity for 1-dye array. It doesnot work for N-dye (N>2) array at
  this time.
  
  Note that if user collapsed the replicates in creating the
  \code{madata} object (see \code{\link[maanova]{createData}}),
  arrayview will be unavailable. 
}

\usage{
arrayview(object, ratio, array, colormap, onScreen=TRUE, ...)
}

\arguments{
  \item{object}{An object of class \code{madata} or \code{rawdata}.}
  \item{ratio}{The data to be ploted. The length of it must be
    equal to the length of the grid locations, .e.g, madata$row and
    madata$col. If ratio is a vector, there will be one plot. If ratio
    is a matrix, there will be one plot for each column. If ratio is not
    provided, \code{link[maanova]{make.ratio}} will be called to
    calculate the ratios from the original data.}
  \item{array}{A list of arrays to be plotted. This variable is only
    valid when \code{ratio} is not provided. Whenever \code{ratio} is
    provided, all columns in ratio will be plotted.}
  \item{colormap}{User specified color map. See
    \code{\link[base]{colors}} for more detail.}
  \item{\dots}{Other parameters to be passed to
    \code{\link[base]{image}}.}
  \item{onScreen}{A logical value to represent whether to display the
    plots on screen or not. If TRUE, x11() (in Unix/Windows) or
    macintosh (in Mac) will be called inside the function. Otherwise,
    it will plot the figure on the current device. Default is TRUE.}
}

\examples{
\dontrun{data(dbldyeswap)
############################
# arrayview plot on rawdata
############################
# arrayview raw data on screen
arrayview(rawdata)
graphics.off()
# arrayview raw data array 1 and 3 and output to postscript file
postscript(file="dbldyeswapArrayview.ps")
arrayview(rawdata, array=c(1,3), onScreen=FALSE)

############################
# RI plot on madata
############################
# make madata object without collapsing replicates
data2 <- createData(rawdata, n.rep=2, avgreps=0)
arrayview(data2)
graphics.off()
}

# once the replicates are collapsed,
# arrayview will be unavailable 
\dontrun{data1 <- createData(rawdata, n.rep=2, avgreps=1)}
\dontrun{arrayview(data1) # get an error here}
}

\keyword{hplot}

\eof
\author{Hao Wu \email{hao@jax.org} }

\name{consensus}
\alias{consensus}

\title{Build consensus tree out of bootstrap cluster result}

\description{
  This is the function to build the consensus tree from the bootstrap
  clustering analysis. If the clustering algorithm is hierarchical
  clustering, the majority rule consensus tree will be built based on
  the given significance level. If the clustering algorithm is K-means, a
  consensus K-means group will be built. 
}

\usage{
consensus(macluster, level = 0.8, draw=TRUE)
}

\arguments{
  \item{macluster}{An object of class \code{macluster}, which is the
    output of \code{\link[maanova]{macluster}}}.
  \item{level}{The significance level for the consensus tree. This is a
    numeric number between 0.5 and 1.}
  \item{draw}{A logical value to indicate whether to draw the consensus
    tree on screen or not.}
}

\value{
  An object of class \code{consensus.hc} or \code{consensus.kmean}
  according to the clustering method.
}

\examples{
# load in data
data(paigen)
# make data object with rep 2
paigen <- createData(paigen.raw, 2)
# make interactive model
model.int.fix <- makeModel(data=paigen,
      formula=~Dye+Array+Strain+Diet+Strain:Diet)
# fit ANOVA model
anova.int <- fitmaanova(paigen, model.int.fix)
# test interaction effect 
\dontrun{test.int.fix <- matest(paigen, model.int.fix, term="Strain:Diet", n.perm=100)
# pick significant genes - pick the genes selected by Fs test
idx <- volcano(test.int.fix)$idx.Fs

# do k-means cluster on genes
gene.cluster <- macluster(anova.int, "Strain:Diet", idx, "gene",
    "kmean", kmean.ngroups=5)
# get the consensus group
consensus(gene.cluster, 0.5)

# HC cluster on samples
sample.cluster <- macluster(anova.int, "Strain:Diet", idx, "sample","hc")
# get the consensus group
consensus(sample.cluster, 0.5)}
}

\seealso{
  \code{\link[maanova]{macluster}}
}

\keyword{cluster}


\eof
\author{Hao Wu \email{hao@jax.org} }

\name{createData}
\alias{createData}

\title{Calculate and create a data object for Micro Array experiment}

\description{
  This is the function to create a \code{madata} object based on the
  given \code{rawdata} and some parameters. 
}

\details{
  The data integrity is checked before making the object. The number of
  rows for the data must be consistent with the number of replicates; the
  number of columns for the data must be consistent with the number of
  dyes, etc.

  Users have the option to collapse the replicated spots. Collapsing
  will be done by taking mean or median of the intensity values for the
  replicated spots. This function assumes the input data is on raw scale.
  So if your data is pre-transformed and on a log2 based,
  collapsing could be wrong.  Also note that once
  the replicated spots are collapsed, you will lose the grid location
  and spatial loess ("rlowess" option in
  \code{\link[maanova]{transform.madata}} will be unapplicable for it.
}

\usage{
createData(rawdata, n.rep=1, avgreps=0, log.trans=TRUE)
}

\arguments{
  \item{rawdata}{An object of class \code{rawdata}, which should be the result
    from \code{\link[maanova]{read.madata}}.}
  \item{n.rep}{An integer to represent the number of replicates.}
  \item{avgreps}{An integer to indicate whether to average the
    replicates or not. 0 means no average; 1 means to take the mean of the
    replicates; 2 means to take the median of the replicates.}
  \item{log.trans}{A logical value to indicate whether to take log2
    transformation on the raw data or not. It is TRUE by default. But
    in the case that your data is pre-transformed, you need to set it to
    FALSE. If this is TRUE, \code{TransformMethod} field will be set to
    "log2".} 
}

\value{
  An object of class \code{madata}, which is a list of following components:
  \item{n.gene}{Total number of genes in the experiment.}
  \item{n.rep}{Number of replicates in the experiment.}
  \item{n.spot}{Number of spots for each gene.}
  \item{data}{data field. It is either the log2 transformed
    rawdata (if log.trans=TRUE), or just the rawdata (if
    log.trans=FALSE).}
  \item{Others}{All other fields in the input object of class \code{rawdata}.}
}

\examples{
#################
# 2-dye arrays
#################
data(paigen)
# create data object with replicate
data2 <- createData(paigen.raw, n.rep=2)
# summarize the data object
summary(data2)
# create data with averaging of replicates
data1 <- createData(paigen.raw, n.rep=2, avgreps=1)
summary(data1)

####################################################################
# affy array - data is pre-transformed so log2 is skipped
####################################################################
data(abf1)
abf1 <- createData(abf1.raw, n.rep=1, log.trans=FALSE)
summary(abf1)
}

\keyword{utilities}


\eof
\name{rawdata}
\alias{rawdata}
\alias{dbldyeswap}

\docType{data}

\title{Data for a double dye-swap experiment}

\description{
  There are four cDNA arrays comparing two samples in a double dye-swap
  design. 
}

\usage{data(rawdata)}

\format{
  An object of class \code{rawdata}.
}

\examples{
data(rawdata)
}

\keyword{datasets}

\eof
\author{Hao Wu \email{hao@jax.org}}

\name{dyeswapfilter}
\alias{dyeswapfilter}

\title{Gene filter for dye-swap experiment}

\description{
  This function is used to flag the questionable spot in any kind of
  dye-swap experiment.

  This function only works for 2-dye arrays.
}

\details{
  For each pair of dye-swap, the difference in log ratios (d) are
  computed. Then compute the IQR (interquartile range) of d and convert
  that to Standard Deviation by SD = IQR/1.35. Any gene with d larger
  than r times SD will be flagged.

  Note that I assume in the input data object, the adjecent arrays is a
  dye-swap pair. 
}
  
\usage{
dyeswapfilter <- function(dataobj, r=4)
}

\arguments{
  \item{dataobj}{An object of class \code{madata} or \code{rawdata}.}
  \item{r}{A cut-off value for bad spot. The genes with log-ratio
    difference larger than r times standard deviation will be flagged.}
}

\value{
  An object of class \code{rawdata} or \code{madata} with the
  \code{flag} field created or updated.
}

\examples{
data(dbldyeswap)
# riplot before filtering
riplot(rawdata)
# filter the gene
rawdata <- dyeswapfilter(rawdata)
# riplot again - some genes are highlighted
riplot(rawdata)
}

\keyword{models}

\eof
\author{Hao Wu \email{hao@jax.org} }

\name{fitmaanova}
\alias{fitmaanova}

\title{Fit ANOVA model for Micro Array experiment}

\description{
  This is the function to fit the ANOVA model for Micro Array
  experiment. Given the data and model object, this function will fit the
  regression gene by gene and output the estimates, variance components
  for random terms, fitted values, etc.
  For a mixed effect models, the output estimates will be BLUE and BLUP.

  Note that the calculation could be very slow for mixed effect
  models. The computational time depends on the number of genes, number
  of arrays and the size of the random variables (dimension of Z
  matrix). 
}

\usage{
fitmaanova(madata, mamodel, inits20,
           method=c("REML","ML","MINQE-I","MINQE-UI", "noest"),
           verbose=TRUE)
}

\arguments{
  \item{madata}{An object of class \code{madata}.}
  \item{mamodel}{An object of class \code{mamodel}.}
  \item{inits20}{The initial value for variance components. This should
    be a matrix with number of rows equals to the number of genes and
    number of columns equals to the number of random terms in the model.
    Good initial values will greatly speed up the calculation. If not
    given, it will be calculated based on the corresponding fixed
    model.}
  \item{method}{The method used to solve the Mixed Model
    Equation. Available options includes: "ML" for maximum liklihood;
    "REML" for restricted maximum liklihood; "MINQE-I" and "MINQE-UI"
    are for minimum norm and "noest" for no estimate
    for variance component (use the initial value). Both "ML" and "REML"
    use method of scoring algorithm to solve MME iteratively. "noest" skips the
    iteration and will be significantly faster (but 
    accurate). Default method is "REML". For details about fitting mixed
    effects models, read the "Fitting mixed Effects model" section.
  } 
  \item{verbose}{A logical value to indicate whether to display some
    message for calculation progress.}
}

\section{Fitting mixed Effects model}{
  Fitting mixed effects models needs a lot of computation. A good
  starting value for the variances is very important. This function
  first treats all random factors as fixed and fits a fixed effects
  model. Then variances for random factors are calculated and used as
  the initial values for mixed effects model fitting. 

  There are several methods available for fitting the mixed effects
  model. "noest" does not really fit the mixed effects model. It takes
  the initial variance and solve mixed model equatinos to get the
  estimates (BLUE and BLUP). "MINQE-I" and "MINQE-UI" are based on
  minimum norm unbiased estimators. It is can be thought as a first
  iterate solution of "ML" and "REML", respectively. "ML" and "REML" are
  based on maximum likelihood and restricted maximum likelihood. Both of
  them need to be solved iteratively so they are verly slow to
  compute. For "ML" and "REML", a MINQUE estimates is used as
  the starting value.  "Method of scoring" is used as the iteratively
  algorithm to solve ML and REML. "Method of scoring" algorithm is
  similar to New-Raphson method except that it uses the expected value
  of Hessian (second derivative matrix of the objective function)
  instead of Hessian itself. Method of scoring is more robust to poor
  starting values and the Hessian is easier to calculate than
  Newton-Raphson.

  For more mathematical details please read Searle et al. 
}



\value{
  An object of class \code{maanova}, which is a list of following
  components:
  \item{yhat}{Fitted pmt value which has the same dimension as the input
    pmt data}
  \item{S2}{Variance components for the random terms. It is a matrix
    with number of rows equals to the number of genes and number of
    columns equals to the number of random terms. Note that for fixed
    effect model, S2 is a one column vector for error's variance.}
  \item{G}{Gene effects. A vector with the same length as the number
    of genes.}
  \item{reference}{The estimates for reference sample. If there is no
    reference sample specified in the design, this field will be absent
    in the output object.}
  \item{S2.level}{A list of strings to indicate the order of the S2
    field. Note that the last column of S2 is always the error's
    variance. S2.level is only for the non-error terms.
    For example, if there are three columns in S2 and S2.level is
    c("Strain", "Diet"), then the three columns of S2
    correspond to the variances of Strain, Diet and error
    respectively for each gene. }
  \item{Others}{Estimates (or BLUE/BLUP for mixed effect model) for
    the terms in model. There will be XXX.level field for each term
    representing the order of the estimates (similar to S2.level).}
  \item{flag}{A vector to indicate whether there is bad spot for this 
    gene. 0 means no bad spot and 1 means has bad spot. If there is no
    flag information in input data, this field will not be available.}
  \item{model}{The model object used for this fitting.}
}

\examples{
###################################
# fixed model fitting
###################################
# load in Paigen's data
data(paigen)
# make data object with rep 2
paigen <- createData(paigen.raw, 2)
# Note that the data is normalized so normalization is skipped
# full model
model.full.fix <- makeModel(data=paigen,
      formula=~Dye+Array+Spot+Strain+Diet+Strain:Diet)
anova.full.fix <- fitmaanova(paigen, model.full.fix)
# residual plot
resiplot(paigen, anova.full.fix)

#######################################
# mixed model fitting -
# Array, Spot and biological
# replicates are random effects. 
# This may take a while to finish
#######################################
\dontrun{model.full.mix <- makeModel(data=paigen,
      formula=~Dye+Array+Spot+Strain+Diet+Strain:Diet+Sample,
      random=~Array+Spot+Sample)
anova.full.mix <- fitmaanova(paigen, model.full.mix, method="REML")
# residual plot
resiplot(paigen, anova.full.mix)
# variance component plot
varplot(anova.full.mix)}
}

\references{
  Kerr and Churchill(2001), Statistical design and the analysis of gene
  expression microarrays, \emph{Genetical Research}, \bold{77}:123-128.
  
  Kerr, Martin and Churchill(2000), Analysis of variance for gene expression
  microarray data, \emph{Journal of Computational Biology},
  \bold{7}:819-837.

  Searle, Casella and McCulloch, \emph{Variance Components}, John Wiley
  and sons, Inc. 
}

\seealso{
  \code{\link[maanova]{makeModel}}, \code{\link[maanova]{matest}}
}

\keyword{models}


\eof
\author{Hao Wu \email{hao@jax.org} }

\name{fom}
\alias{fom}

\title{Figure of Merit}

\description{
  K-means clustering needs a given number of groups, which is difficult to
  guess in most of the cases. This function calculates the Figure of
  Merit values for different number of groups and generates the FOM
  plot (FOM value versus number of groups). Lower FOM value means
  better grouping. User can decide the number of groups in kmeans
  cluster based on that result.
}

\usage{
fom(anovaobj, idx.gene, term, ngroups)
}

\arguments{
  \item{anovaobj}{An object of class \code{maanova}.}
  \item{idx.gene}{The index of genes to be clustered.}
  \item{term}{The factor (in formula) used in clustering. The expression
    level for this term will be used in clustering. This term has to 
    correspond to the gene list, e.g, idx.gene in this function. The
    gene list should be the significant hits in testing this term.}
  \item{ngroups}{The number of groups for K-means cluster. This could be
    a vector or an integer.}
}

\value{
  A vector of FOM values for the given number of groups
}

\examples{
# load in data
data(paigen)
# make data object with rep 2
paigen <- createData(paigen.raw, 2)
# make interactive model
model.int.fix <- makeModel(data=paigen,
      formula=~Dye+Array+Strain+Diet+Strain:Diet)
# fit ANOVA model
\dontrun{anova.int <- fitmaanova(paigen, model.int.fix)
# test interaction effect 
test.int.fix <- matest(paigen, model.int.fix, term="Strain:Diet", n.perm=100)
# pick significant genes - pick the genes selected by Fs test
idx <- volcano(test.int.fix)$idx.Fs
# generate FOM
m <- fom(anova.int, idx, "Strain:Diet", 10)}
}

\references{
  Yeung, K.Y., D.R. Haynor, and W.L.Ruzzo (2001). Validating clustering
  for gene expression data. \emph{Bioinformatics}, \bold{17:309-318}.
}

\seealso{
  \code{\link[maanova]{macluster}},
  \code{\link[maanova]{consensus}},
  \code{\link[mva]{kmeans}}
}

\keyword{models}


\eof
\author{Hao Wu \email{hao@jax.org} }

\name{geneprofile}
\alias{geneprofile}

\title{Expression plot for selected genes}

\description{
  This function generate a plot with many lines. Each line represents
  a gene. The y-axis is the estimated expression level for the given
  factor from ANOVA model. The x-axis is for the levels of the
  give factor, e.g.,  different strains. 
}

\usage{
geneprofile(anovaobj, term, geneidx,
            col="blue", type="b", ylim, xlab, ylab, ...)
}

\arguments{
  \item{anovaobj}{An object of class \code{maanova}. It should be the
    result from \code{\link[maanova]{fitmaanova}}.}
  \item{term}{The terms to be plotted.}
  \item{geneidx}{The index of genes to be plotted.}
  \item{col}{The color to be used in plot.}
  \item{type}{The line type.}
  \item{ylim}{Y-axis limit.}
  \item{xlab}{X-axis label.}
  \item{ylab}{Y-axis label.}
  \item{\dots}{Other parameters to be passed to
    \code{\link[base]{plot}}.}
}

\examples{
# load in data
data(paigen)
# make data object with rep 2
paigen <- createData(paigen.raw, 2)
# make an additive model
model.add.fix <- makeModel(data=paigen, formula=~Dye+Array+Strain+Diet)
# fit ANOVA model
anova.add <- fitmaanova(paigen, model.add.fix)
# test strain effect
\dontrun{test.Strain.fix <- matest(paigen, model.add.fix, term="Strain", n.perm=100)
# volcano plot
idx <- volcano(test.Strain.fix)

# do gene profile for the selected genes
geneprofile(anova.add, "Strain", idx$idx.all)}
}

\keyword{hplot}

\eof
\author{Hao Wu \email{hao@jax.org} }

\name{gridcheck}
\alias{gridcheck}

\title{Plot grid-by-grid data comparison for arrays}

\description{
  This function is used to check microarray data quality. It can
  check the data within the same array or cross different arrays.

  Normally, on one array, the pmt data for both channels (CY5 and CY3)
  should be highly correlated (also apparent on the RI plot). The pmt data
  for the same sample on different arrays should be highly correlated
  too. Normally if an error happened in gridding, only a few blocks
  will be misgridded. This function does the scatter plot on a grid basis
  to check the quality of hybridazition and gridding. 

  If you only provide array1 (either an integer or a vector), it will do
  grid check within the same array, that is, for each slide, there will
  be one scatter plot for log2(Red) versus log2(Green) for each grid.
  If you provide array1 and array2 (both need to be one integer), it
  will check the data for the same sample (sample ID information is in
  experimental design) for these two arrays. If there's no common sample
  on these two arrays, the function will report an error. 
  
  In either case, you should see a nearly linear curve in all
  plots. If there were errors in hybridization and/or gridding, some of
  the plots will look messy. Then you have to check if something wrong
  happened, e.g., miss labeling, wrong gridding, etc.

  If you don't have grid information for the data, this function will be
  unavailable.

  Note that this function only works for 2-dye array.
}

\usage{
gridcheck(rawdata, array1, array2, highlight.flag = TRUE, flag.color = "Red",
          margin = c(3.1, 3.1, 3.1, 1.1)) 
}

\arguments{
  \item{rawdata}{An object of class \code{rawdata}.}
  \item{array1}{A list of array numbers for which you want to do grid
    checking. All arrays will be checked by default. If you want to
    compare the same sample across arrays, this parameter must be an
    integer to indicate the first array number.}
  \item{array2}{The second array number if you want to do cross array
    comparisons.} 
  \item{highlight.flag}{A logical parameter to indicate whether to
    highlight the bad spot or not.}
  \item{flag.color}{The color for bad spot; default is red.}
  \item{margin}{A numerical vector of the form c(bottom, left, top,
    right) which gives the lines of the margin to be specified on the four
    sides of the plot. Read \code{\link[base]{par}} for details.}
}

\note{
  This function will plot one figure for each array. So if you have many
  arrays, there will be many figures generated.
}

\examples{
# load in data
\dontrun{data(dbldyeswap)
# grid check on all arrays
gridcheck(rawdata, margin=c(1,1,1,1))
graphics.off()
# grid check array 1 versus array 2
gridcheck(rawdata, array1=1, array2=2, margin=c(1,1,1,1))
graphics.off()}
}

\keyword{hplot}



\eof
\name{kidney.raw}
\alias{kidney.raw}
\alias{kidney}

\docType{data}

\title{Kidney Data from CAMDA}

\description{
This is a 24-array double reference
design. Six samples are compared to a reference with dye swapped
and all arrays are duplicated. Flag for bad spots is included in the
data.
}

\usage{data(kidney.raw)}
\format{
    An object of class \code{rawdata}.
}

\source{
  \item http://www.camda.duke.edu
}
\references{
  \item Prichard CC, Hsu L, Delrow J and Nelson PS (2001),
  Project normal: defining normal variance in mouse gene expression,
  \textit{PNAS}, 98:13266
}

\examples{
data(kidney.raw)
}

\keyword{datasets}

\eof
\name{maanova-internal}
\alias{JS}
\alias{JSshrinker}
\alias{buildtree}
\alias{calPval}
\alias{calVolcanoXval}
\alias{caldf}
\alias{check.confounding}
\alias{checkContrast}
\alias{cluster2num}
\alias{consensus.hc}
\alias{consensus.kmean}
\alias{dist.cor}
\alias{findgroup}
\alias{getPval.volcano}
\alias{glowess}
\alias{intprod}
\alias{linlog}
\alias{linlog.engine}
\alias{linlogshift}
\alias{locateTerm}
\alias{make.ratio}
\alias{makeAB}
\alias{makeCompMat}
\alias{makeD}
\alias{makeDesign}
\alias{makeHq}
\alias{makeShuffleGroup}
\alias{makeZiZi}
\alias{makelevel}
\alias{matest.engine}
\alias{matest.perm}
\alias{meanvarlog}
\alias{plot.consensus.hc}
\alias{plot.consensus.kmean}
\alias{print.maanova}
\alias{print.madata}
\alias{print.summary.madata}
\alias{print.summary.mamodel}
\alias{ratioVarplot}
\alias{rlowess}
\alias{shift}
\alias{shuffle.maanova}
\alias{solveMME}
\alias{summary.madata}
\alias{summary.mamodel}
\alias{volcano.ftest}
\alias{volcano.ttest}
\alias{blkdiag}
\alias{colmax}
\alias{colmin}
\alias{makeContrast}
\alias{matrank}
\alias{matsort}
\alias{mixed}
\alias{norm}
\alias{num2yn}
\alias{ones}
\alias{parseformula}
\alias{pinv}
\alias{repmat}
\alias{rowmax}
\alias{rowmin}
\alias{sumrow}
\alias{zeros}
\alias{fdr}

\usage{
JS(X, var)
JSshrinker(X, df, meanlog, varlog)
buildtree(ct, binstr, depth, parent, idx.node, idx.leave)
calPval(fstar, fobs, pool)
calVolcanoXval(matestobj)
caldf(model, term)
check.confounding(model, term1, term2)
checkContrast(model, term, Contrast)
cluster2num(clust)
consensus.hc(macluster, level, draw)
consensus.kmean(macluster, level, draw)
dist.cor(x)
findgroup(varid, ndye)
getPval.volcano(matestobj, method, idx)
glowess(object, method, f, iter, degree, draw)
intprod(terms, intterm)
linlog(object, cg, cr, draw)
linlog.engine(data, cutoff)
linlogshift(object, lolim, uplim, cg, cr, n.bin, draw)
locateTerm(labels, term)
make.ratio(object, norm.std=TRUE)
makeAB(ct, coord, treeidx, startx, maxdepth)
makeCompMat(n)
makeD(s20, dimZ)
makeDesign(design)
makeHq(s20, y, X, Z, Zi, ZiZi, dim, b, method)
makeShuffleGroup(sample.mtx, ndye, narray)
makeZiZi(Z, dimZ)
makelevel(model, term)
matest.engine(anovaobj, term, mv, test.method, Contrast,
              is.ftest, partC, verbose=FALSE)
matest.perm(n.perm, FobsObj, data, model, term, Contrast, inits20,
            mv, is.ftest, partC, MME.method, test.method,
            shuffle.method, pool.pval)
meanvarlog(df)
plot.consensus.hc(x, title, \dots)
plot.consensus.kmean(x, \dots)
print.maanova(x, \dots)
print.madata(x, \dots)
print.summary.mamodel(x, \dots)
ratioVarplot(logsum, logdiff, n)
rlowess(object, method, grow, gcol, f, iter, degree, draw)
shift(object, lolim, uplim, draw)
shuffle.maanova(data, model, term)
solveMME(s20, dim, XX, XZ, ZZ, a)
summary.madata(object, \dots)
summary.mamodel(object, \dots)
volcano.ftest(matestobj, threshold, method, title,highlight.flag)
volcano.ttest(matestobj, threshold, method, title,highlight.flag,
   onScreen)
matsort(mat, index=1)
repmat(mat, n.row, n.col, \dots)
zeros(dim)
ones(dim)
blkdiag(...)
rowmax(x)
rowmin(x)
colmax(x)
colmin(x)
sumrow(x)
matrank(X)
norm(X)
mixed(y, X, Z, XX, XZ, ZZ, Zi, ZiZi, dimZ, s20, method =
      c("noest", "MINQE-I", "MINQE-UI", "ML", "REML"),
      maxiter = 100)
parseformula(formula, random, covariate)
makeContrast(model, term)
pinv(X, tol)
fdr(p, method = c("stepup", "adaptive", "stepdown"))
}

\title{Internal maanova functions}

\description{
  Internal maanova functions. These are generally not to be called by
  the user. 
}

\details{
  Some funtion descriptions are:
    \itemize{
    \item matsort: Sort matrix in ascending order along specified dimension
    \item repmat: Replicate and tile an array
    \item zeros: Create an array with all zeros
    \item ones: Create an array with all ones
    \item blkdiag: Block diagonal concatenation of input arguments
    \item num2yn: convert a logical value to string "Yes" or "No"
    \item rowmax, rowmin, colmax, colmin: find the maximum/minimum value
    for row/columns
    \item sumrow: calculate the sum of rows for a given matrix
    \item matrank: calculate the rank of a matrix
    \item norm: calculate matrix or vector norm, working only for vector
    now
    \item mixed: engine function to solve Mixed Model Equations using EM
    algorithm
    \item parseformula: parse input formula. This is used for mixed
    effect model
    \item makeDesign: function to make a integer list from input design object
    \item intpord: function to make the design matrix for interaction terms
    it's working for two way interaction only
    \item makeContrast: function to make the contrast matrix given model
    and the term to be tested
    number of levels
    \item pinv: calculate the pseudo inverse for a singular matrix.
    Note that I was using ginv function in MASS but it is not
    robust, e.g., sometimes have no result. That's because
    the engine function dsvdc set the maximum number of iteration
    to be 30, which is not enough in some case.
    I use La.svd instead of svd in my function.
    I don't want to spend time on it so it doesn't support complex
    number
    \item fdr: function to calculate the adjusted P values for FDR control.
  }

}

\examples{
# for matsort
a<-matrix(c(1,6,4,3,5,2),2,3)
matsort(a,1)
matsort(a,2)

# for ones and zeros
ones(c(2,2))
zeros(c(2,3,2))

# for repmat
a<-c(1,2)
repmat(a,2,1)
a<-matrix(1:4,2,2)
repmat(a,1,2)

# for blkdiag
a<-matrix(1:4,2,2)
b<-matrix(3:6,2,2)
blkdiag(a,b)
blkdiag(a,b,c(1,2))

# others examples are omitted

}

\author{Hao Wu, \email{hao@jax.org} }

\keyword{internal}

\eof
\author{Hao Wu \email{hao@jax.org} }

\name{macluster}
\alias{macluster}

\title{Clustering analysis for Micro Array experiment }

\description{
  This function bootstraps K-means or hierarchical clusters and builds a 
  consensus tree (consensus group for K-means) from the bootstrap
  result.
}

\details{
  Normally after the F test, user can select a list of differential expressed
  genes. The next step is to investiagte the relationship among these
  genes. Using the expression levels of these genes, the user can cluster the
  genes or the samples using either hierarchical or K-means clustering
  algorithm. In order to evaluate the stability of the relationship,
  this function bootstraps the data, refits the model and recluster the
  genes/samples. Then for a certain number of bootstrap iterations, say,
  1000, we have 1000 cluster results. We can use
  \code{\link[maanova]{consensus}} to  build the consensus tree from
  these 1000 trees. 

  Note that if you have a large number (say, more than 100) of
  genes/samples to cluster, hierarchical clustering could be very
  unstable. A slight change in the data can result in a big change in the
  tree structure. In that case, K-means will give better results.
}

  
\usage{
macluster(anovaobj, term, idx.gene, what = c("gene", "sample"), 
    method = c("hc", "kmean"), dist.method = "correlation",
    hc.method = "ward", kmean.ngroups, n.perm = 100)
}

\arguments{
  \item{anovaobj}{The result object for fitting ANOVA model.}
  \item{term}{The factor (in formula) used in clustering. The expression
    level for this term will be used in clustering. This term has to 
    correspond to the gene list, e.g, idx.gene in this function. The
    gene list should be the significant hits in testing this term.}
  \item{idx.gene}{A vector indicating the list of differential expressed
    genes. The expression level of these genes will be used to construct
    the cluster.}
  \item{what}{What to be clustered, either gene or sample.}
  \item{method}{The clustering method. Right now hierarchical clustering
    ("hc") and K-means ("kmean") are available.}
  \item{dist.method}{Distance measure to be used in hierarchical
    clustering. Besides the methods listed in \code{\link[mva]{dist}},
    there is a new method "correlation" (default). The "correlation"
    distance equals to (1 - $r^2$), where r is the sample correlation
    between observations. }
  \item{hc.method}{The agglomeration method to be used in hierarchical
    clustering. See \code{\link[mva]{hclust}} for detail.}
  \item{kmean.ngroups}{The number of groups for K-means cluster.}
  \item{n.perm}{Number of bootstraps. If it is 1, this function will
    cluster the observed data. If it is bigger than 1, a bootstrap
    will be performed.}
}

\value{
  An object of class \code{macluster}.
}

\seealso{
  \code{\link[mva]{hclust}}, \code{\link[mva]{kmeans}},
  \code{\link[maanova]{consensus}}
}

\examples{
# load in data
data(paigen)
# make data object with rep 2
paigen <- createData(paigen.raw, 2)
# make interactive model
model.int.fix <- makeModel(data=paigen,
      formula=~Dye+Array+Strain+Diet+Strain:Diet)
# fit ANOVA model
anova.int <- fitmaanova(paigen, model.int.fix)
# test interaction effect 
\dontrun{test.int.fix <- matest(paigen, model.int.fix, term="Strain:Diet", n.perm=100)
# pick significant genes - pick the genes selected by Fs test
idx <- volcano(test.int.fix)$idx.Fs

# do k-means cluster on genes
gene.cluster <- macluster(anova.int, "Strain:Diet", idx, "gene",
    "kmean", kmean.ngroups=5)
# get the consensus group
consensus(gene.cluster, 0.5)

# HC cluster on samples
sample.cluster <- macluster(anova.int, "Strain:Diet", idx, "sample","hc")
# get the consensus group
consensus(sample.cluster, 0.5)}
}

\keyword{cluster}
  

\eof
\author{Hao Wu \email{hao@jax.org} }

\name{makeModel}
\alias{makeModel}

\title{Make model object for N-dye Micro Array experiment}

\description{
  This is the function to make an object of class \code{mamodel} 
  for a Micro Array experiment. 
}

\details{
  The user needs to specify the ANOVA model by formula. It can be a fixed or
  mixed effect model. This function will check the validity of the data,
  calculate some parameters, construct and design matrices and wrap up
  everything together to create an output object.

  The model formula is for a gene-specific model. All terms in the
  formula should be corresponding to the factor names in design except
  "Spot" and "Label". "Spot" represents the spotting effect and "Label"
  represents the labelling effects. They are from the within slide
  technical replicates. If there is no replicated spots, These two terms
  cannot be fitted. Also these two terms cannot be fitted for one-dye
  system (e.g., affymetric arrays). (Note that Dye effect should not be
  fitted in one-dye system).

  A typical formual will be like "~Array+Dye+Sample", which means you
  want to fit Array effect, Dye effect and Sample effect in the ANOVA
  model. In this case, you need to have Array, Dye and Sample columns in
  your input design file. Make sure you have enough degree of
  freedom when making a model. Also you need to be careful about
  confounding problem.
  
  If you have multiple factors in your experiment, you can specify the main
  and interaction effect in the formula. At this time, only two-way
  interactions are allowed.

  For most mixed effect models, Array should be treated as random
  factor. Sample should be treated as random if you have biological
  replicates. Note that the reference sample (0's in Sample) will
  always be treated as fixed even if you specify Sample as random.
}

\usage{
makeModel(data, design, formula, random=~1, covariate=~1)
}

\arguments{
  \item{data}{An object of class \code{madata}.}
  \item{design}{A data frame representing the experimental design. By
    default, it is a field in madata. But you can always make a data
    frame and pass it to the function.}
  \item{formula}{The ANOVA model formula.}
  \item{random}{The formula for random terms. ~1 means only the residual
    is random (fixed model). Note that all random terms should be in the
    ANOVA model formula.}
  \item{covariate}{The formula for covariates. ~1 means no covariates.
    The covariates will be continuous values in the design matrix.}
}

\value{
  An object of class \code{mamodel} with the following fields:
  \item{X}{Design matrix for fixed terms.}
  \item{dimX}{Number of columns in X for each fixed term.}
  \item{Z}{Design matrix for random terms. This will be absent for fixed
  model.}
  \item{dimZ}{Number of columns in Z for each random term.This will be
    absent for fixed model.}
  \item{df}{The degree of freedom for each term in the model.}
  \item{mixed}{An integer to indicate whether this is a fixed or mixed
    effect model. 0 means fixed and 1 means mixed.}
  \item{design}{The input experimental design as a data frame.}
  \item{formula}{The input model formula.}
  \item{random}{The input formula for random terms.}
  \item{covariate}{The input formula for covariates.}
}

\examples{
#load in data
data(paigen)
# make data object with rep 2
paigen <- createData(paigen.raw, 2)
# make full model for fixed effect model
model.full.fix <- makeModel(data=paigen,
      formula=~Dye+Array+Spot+Strain+Diet+Strain:Diet)
summary(model.full.fix)
# make full model for mixed effect model
model.full.mix <- makeModel(data=paigen,
      formula=~Dye+Array+Spot+Strain+Diet+Strain:Diet+Sample,
      random=~Array+Spot+Sample)
summary(model.full.mix)
}

\references{
  Kerr and Churchill(2001), Statistical design and the analysis of gene
  expression microarrays, \emph{Genetical Research}, \bold{77}:123-128.
  
  Kerr, Martin and Churchill(2000), Analysis of variance for gene expression
  microarray data, \emph{Journal of Computational Biology},
  \bold{7}:819-837.
}

\keyword{models}

\eof
\author{Hao Wu \email{hao@jax.org} }

\name{matest}
\alias{matest}

\title{Statistical test for Microarray experiment}

\description{
  This is the function to perform F or T test on one or multiple
  experimental factor(s). Permutation test will be carried upon request.
}

\details{
  If user provide a comparision matrix, this function will perform T-test
  on the given comparison(s). Otherwise, this function will perform
  F-test for the given term.
  
  There are four types of tests available. All four tests are based on the
  gene-specific ANOVA model.  F1 is the usual F statistic. F3 assumes
  common error variance across all genes. F2 is the hybrid of the F1 and
  F3 tests. Fs is based on the James-Stein shrinkage estimates of the
  error variance.
  
  Permutation tests can run on MPI cluster. 
  This feature is only available for Unix/Linux system. Several
  other R packages (such like SNOW, Rmpi, etc.) are needed for using
  cluster. You may need help from your system administrator to setup LAM-MPI
  correctly. For detailed information on LAM-MPI cluster setup and the
  cluster usage in R, read "MPI\_README" distributed with the package.
}

\usage{
matest(data, model, term, Contrast, n.perm=1000, nnodes=1,
      shuffle.method=c("sample", "resid"),
      MME.method=c("REML","noest","ML"),
      test.method=c(1,0,1,1),
      pval.pool=TRUE, verbose=TRUE)
}

\arguments{
  \item{data}{An object of class \code{madata}.}
  \item{model}{An object of class \code{mamodel}.}
  \item{term}{The term(s) to be tested. It can be multiple terms. Note
    that the tested term must be fixed. If the term to be tested is a
    random term, it will be converted to a fixed term than do test.}
  \item{Contrast}{The comparison matrix for the term. The number of
    columns equals to the number of levels in the term. The number of
    rows is the number of T-test you want to carry. Note that it must
    be a matrix. Use \code{\link[base]{matrix}} command to make it. If
    this is provided, T-test will be performed. Otherwise, F-test will
    be performed on the term.}
  \item{n.perm}{An integer for number of permuatations.}
  \item{nnodes}{Number of nodes in the MPI cluster. If 1, the
    permutation test will be running on the local computer.}
  \item{shuffle.method}{Data shuffling method. "sample" for sample
    shuffling and "resid" for residual shuffling. Read "Data Shuffling"
    section for detail.}
  \item{MME.method}{The method used to solve the Mixed Model Equations. See
    \code{\link[maanova]{fitmaanova}} for detail. This parameter only
    applies for mixed effects model permutation test. Default method is
    "REML". The variance components for observed data will be used
    for permuted data. It will greatly increase the speed but you may
    lose power in statistical test in some cases.}
  \item{test.method}{An integer vector of four elements to indicate
    which F test to carry. Default is c(1,0,1,1), which means do F1, F3
    and Fs test.}
  \item{pval.pool}{A logical value to indicate whether to use pooled
    permutation F values to calculate the P values.}
  \item{verbose}{A logical value to indicate whether to display some
    message for calculation progress.}
}

\section{Data Shuffling}{
  Data shuffling method is a crucial part in the permutation
  test. Currently there are two shuffling method available, residual
  shuffing and sample shuffing. Fixed-effects models permutation test
  can use either of the method. For mixed-effects models, residual
  shuffing will be incorrect so only sample shuffing is available. 
  
  Residual shuffing is to shuffle the null model residuals globally
  without replacement. 

  Sample shuffing is to shuffle the samples based on the nesting
  relationship among the experimental factors in the model. For sample
  shuffling, you need to make sure you have a 
  good sample size. Otherwise the result may be biased.
}


\value{
  An object of class \code{matest}, which is a list of the following
  components:
  \item{model}{Input model object.}
  \item{term}{The input term(s) to be tested.}
  \item{dfde}{Denominator's degree of freedom for the test.}
  \item{dfnu}{Numerator's degree of freedom for the test. Note that this
    is always 1 for T-test.}
  \item{obsAnova}{An object of \code{maanova}, which is the ANOVA model
    fitting result on the original data.}
  \item{Contrast}{The contrast matrix used in the test.}
  \item{n.perm}{Number of permutations.}
  \item{shuffle}{Shuffle style}
  \item{pval.pool}{Use pooled P value or not.}
  \item{F1, F2, F3, Fs}{Objects of four different F tests results. All or
    any of them could be there according to the requested F test
    method. Each of them contains the following fields:
    \itemize{
      \item{Fobs}{F value for the observed data.}
      \item{Ptab}{Tabulated P values for the observed data.}
      \item{Pvalperm}{Nominal permutation P values for each gene. This
	field will be unavailable if user didnot do permutation test.}
      \item{Pvalmax}{FWER one-step adjusted P values from the permutation
	test.}
    }
    All the F values and P values are matrices. The number of rows in
    the matrices equals to the number of genes. For F-test, the number
    of columns will be one. For T-test, the number of columns equals
    to the number of tests carried.
  }

}

\examples{
# load in Paigen's data
data(paigen)
# make data object with rep 2
paigen <- createData(paigen.raw, 2)
# Note that the data is normalized so normalization is skipped

##################################
# fixed model test
##################################
# make an additive model
model.add.fix <- makeModel(data=paigen, formula=~Dye+Array+Strain+Diet)
# test strain effect
\dontrun{test.Strain.fix <- matest(paigen, model.add.fix, term="Strain", n.perm=100)}
# volcano plot
\dontrun{idx <- volcano(test.Strain.fix)}

# test pairwise comparisions for Strain, using a MPI cluster with 8 nodes
\dontrun{C <- matrix(c(1,-1,0,1,0,-1, 0,1,-1), nrow=3, byrow=TRUE)}
\dontrun{ttest.strain.fix <- matest(paigen, model.add.fix,
         term="Strain", Contrast=C, n.perm=100, nnodes=8)}
\dontrun{volcano(ttest.strain.fix)}

##################################
# mixed model test
##################################
# mixed model permutation test is very slow
# I will skip the example for that
# the syntax of the function will be the same
# except the input model object is for mixed effects model
}

\keyword{models}

\references{
  Cui, X. and Churchill,GA (2003), Statistical tests for differential
  expression in cDNA Microarray Expeirments, \emph{Genome Biology} 4:210. 

  Cui, X., Hwang, J.T.G., Blades N., Qiu J. and Churchill GA (2003),
  Improved statistical tests for differential gene expression by
  shrinking variance components, to be submitted.
}

\seealso{
  \code{\link[maanova]{makeModel}}, \code{\link[maanova]{fitmaanova}}
}

\eof
\name{paigen.raw}
\alias{paigen.raw}
\alias{paigen}

\docType{data}

\title{Data for a multiple factor 28-array expeirment}

\description{
This is a multiple factor 28-array experiment.
The experiment is done in Beverly Paigen's Lab in The Jackson Lab.
They took three strains of mice and feed them with two kind of
diets. In that way you get six kind of mice. They picked two
individuals in each group then you have totally 12 distinct mice.
So in this experiment, you have strain, diet and biological replicates
as the factors. You can test the effects from any factor or
any combination of them.
}

\usage{data(paigen.raw)}

\format{
    An object of class \code{rawdata}.
}

\examples{
data(paigen.raw)
}

\keyword{datasets}

\eof
\author{Hao Wu \email{hao@jax.org} }

\name{read.madata}
\alias{read.madata}

\title{Read Micro Array data from TAB delimited simple text file}

\description{
  This is the function to read MicroArray experiment data from a TAB 
  delimited simple text file. 
}

\section{Preparing data file}{
  Before using the package, user need to prepare the input data
  file. The data file is a TAB delimited text file. In this file, each
  row corresponding to a gene. In the columns, you can put some gene
  specific information, e.g., the Clone ID, Gene Bank ID, etc. and the
  grid location of the spot. But most importantly you need to put the
  pmt data after that. Most of the MicroArray gridding softwares
  generate one file for each slide. At this point, you need to manually
  combine them into the data file. You need to decide which data you
  want to use in analysis, e.g., mean versus median, backgroud
  subtracted or not, etc. For N-dye array, your pmt data should have N
  columns for each array.  These N columns need to
  be adjacent to each other. You can put the spot flag as a column after
  pmt data for each array. (Note that if you have flag, you will have N+1
  columns data for each array.) If you have replicates, replicated
  measurements of the same clone on the same array should appear in
  adjacent rows.   

  For example, for a 2-dye cDNA array,
  you have four slides scanned by Gene Pix and you get four
  files. First you open your favorite Spreed Sheet editor, e.g., MS
  Excel. Copy your clone ID and Cluster ID to the first 2 columns. Then
  open one of the files generated by Gene Pix, copy the grid location
  into next 4 columns (you only need to do this once because they are
  all the same for four slides). Then for all four files, copy the two
  columns of foreground median value (if you want to use it) and one
  column of flag to the file in the order of Cy5, Cy3, flag. Then select
  the whole file and row sort it according to Clone ID. Save the file as
  tab delimited text file and you are done.


  The data file must be "full", that is, all rows have to have same
  number of fields. Sometimes leading and trailing TAB in the text file
  will bring problems, depends on the operating system. So user need to
  be careful about that.
}

\section{Preparing design file}{
  Design file is another TAB delimited text file. Number of rows of this
  file equals number of arrays times N (the number of dyes).
  Number of columns of this file
  depends on the experimental design. For example, you can have
  "Strain", "Diet", "Sex", etc. in your design file. You *MUST* have a
  column named "Sample" (case sensitive) in the design file. It should be 
  integers to represent the biological individuals. Reference samples
  should have Sample number to be zero(0). Reference sample will always be
  treated as fixed factor in mixed model and it will not be involved in
  any test. You also must have "Array" and "Dye" columns in the design
  file. You must NOT have "Spot" and "Label" columns. They are reserved
  for spotting and labelling effects. 

  Note that you don't have to *USE* all factors in design file. In
  making the model object in \code{\link[maanova]{makeModel}}, the
  experimental design will be determined by the design and a formula.
  You can put all factors in design file but turn them on/off in
  formula.
}

\section{Read pre-transformed data}{
  You can use other softwares to do data transformation and read in the
  pre-transformed data into R/maanova. If that is the case, you should
  skip the log2 transformation in \code{\link[maanova]{createData}} by
  setting log.trans=FALSE. And you should do
  \code{\link[maanova]{riplot}} and \code{\link[maanova]{arrayview}}
  on the result of \code{createData}. Because \code{riplot} and
  \code{arrayview} assume the data in \code{rawdata} object is on raw
  scale.
}

\usage{
read.madata(datafile, designfile="design.txt", header=TRUE, spotflag=TRUE,
            metarow, metacol, row, col, pmt, ...)
}

\arguments{
  \item{datafile}{The data file name with path name as a string.}
  \item{designfile}{The design file name with path as a string.}
  \item{header}{A logical value indicating whether the data file
    contains the column headers.}
  \item{spotflag}{A flag to indicate whether the input file contain the
    flag for bad spot or not.}
  \item{metarow}{The column number for meta row. Default values are 1s.}
  \item{metacol}{The column number for meta column. Default values are 1s.}
  \item{row}{The column number for row. Default value is NA.}
  \item{col}{The column number for column. Default value is NA.}
  \item{pmt}{The start column number for pmt data.}
  \item{\dots}{Other gene information in the data file.}
}

\value{
  An object of class \code{rawdata}, which is a list of following
  components:
  \item{n.array}{Number of arrays in the experiment.}
  \item{n.dye}{Number of dyes.}
  \item{data}{Two channel experiment data.}
  \item{flag}{A matrix for spot flag. Each element corresponding to one
    spot. 0 means normal spot, all other values mean bad spot.}
  \item{metarow}{Meta row for each spot.}
  \item{metacol}{Meta column for each spot.}
  \item{row}{Row for each spot.}
  \item{col}{Column for each spot.}
  \item{ArrayName}{A list of strings to represent the names of the pmt
    data. There are two names per array.}
  \item{design}{An object to represent the experimental design.}
  \item{Others}{Other experiment information listed in the data file and
     specified by user.}
}

\examples{
# note that data files are not distributed with the package,
# read in a file with spot flag
\dontrun{kidney.raw <- read.madata("kidney.txt", designfile="kidneydesign.txt", 
        metarow=1, metacol=2, col=3, row=4, Name=5, ID=6,
        pmt=7, spotflag=TRUE)}
# read in a file without spot flag
\dontrun{rawdata <- read.madata("paigen.txt", designfile="design.txt",cloneid=1, 
        metarow=2, metacol=3, row=4, col=5, pmt=6, spotflag=FALSE)}
}

\keyword{IO}

\eof
\author{Hao Wu \email{hao@jax.org} }

\name{resiplot}
\alias{resiplot}

\title{Residual plot for Micro Array Experiment}

\description{
  This is the function to plot the residuals versus fitted value figure. Two
  channels, e.g., red and green, are drawn in seperate figures.
}

\usage{
resiplot(madata, anovaobj, header)
}

\arguments{
  \item{madata}{An object of class \code{madata}.}
  \item{anovaobj}{An object of class \code{maanova}, which is the output
    from \code{\link[maanova]{fitmaanova}}.}
  \item{header}{Optional. The title of the figure. The default figure
    title will be "Residual vs. Yhat plot".}
}

\examples{
# load in Paigen's data
data(paigen)
# make data object with rep 2
paigen <- createData(paigen.raw, 2)
# Note that the data is normalized so normalization is skipped
# full model
model.full.fix <- makeModel(data=paigen,
      formula=~Dye+Array+Spot+Strain+Diet+Strain:Diet)
anova.full.fix <- fitmaanova(paigen, model.full.fix)
# residual plot
resiplot(paigen, anova.full.fix)
}

\keyword{hplot}

\eof
\author{Hao Wu \email{hao@jax.org} }

\name{riplot}
\alias{riplot}

\title{Ratio intensity plot for 2-dye Micro Array experiment}

\description{
  This function only works for 2-dye array at this time. It will
  plot the log-ratio (log2(R/G)) versus log-intensity (log2(R*G)/2)
  figure for Micro Array experiment. Ideal RI plot will be points
  scattered around the y=0 horizontal line.

  This function works for both \code{rawdata} and \code{madata}. 
  This function and \code{\link[maanova]{arrayview}} assume the data
  field in \code{rawdata} is on the raw scale, and in \code{madata} is
  on log2 based scale. So if your rawdata is pre-transformed, you should
  not do riplot on the raw data.
}

\usage{
riplot(object, title, array, color = "blue", highlight.flag = TRUE, 
    flag.color = "Red", idx.highlight, highlight.color = "Green", 
    rep.connect = FALSE, onScreen=TRUE) 
}

\note{
  This function will plot one figure for each array. So if you have many
  arrays, there will be many figures generated.
}

\arguments{
  \item{object}{An object of class \code{madata} or \code{rawdata}.}
  \item{title}{The title for figures. The default figure title is "RI
    plot for array number X". If the user wants to provide titles, be
    sure to provide a string array with the same number of elements as
    the number of arrays.}
  \item{array}{A list of arrays numbers for which you want to draw an RI
    plot.} 
  \item{color}{The color for the points in scatter plot. Default is blue.}
  \item{highlight.flag}{A logical parameter to indicate whether to
    highlight the bad spots or not.}
  \item{flag.color}{The color for bad spots, default is red.}
  \item{idx.highlight}{A vector for highlighted spots other than bad
    spots.}
  \item{highlight.color}{The color for highlighted spots. Default is green.}
  \item{rep.connect}{A logical value to represent whether to connect the
    dots between the replicates or not.}
  \item{onScreen}{A logical value to represent whether to display the
    plots on screen or not. If TRUE, x11() (in Unix/Windows) or
    macintosh() (in Mac) will be called inside the function. Otherwise,
    it will plot the figure on the current device. Default is TRUE.}
}

\examples{
\dontrun{data(dbldyeswap)
############################
# riplot on rawdata
############################
# riplot raw data on screen
riplot(rawdata)
graphics.off()
# riplot raw data array 1 and 3 and output to postscript file
postscript(file="dbldyeswapRIplot.ps")
riplot(rawdata, array=c(1,3), onScreen=FALSE)

############################
# RI plot on madata
############################
# create data object with collapsing replicates
data1 <- createData(rawdata, n.rep=2, avgreps=1)
# do RI plot for all arrays
riplot(data1)
graphics.off()}
}

\keyword{hplot}


\eof
\author{Hao Wu \email{hao@jax.org} }

\name{subset.madata}
\alias{subset.madata}

\title{Subsetting Micro Array data objects}

\usage{
subset.madata(x, arrays, genes, \dots)
}

\description{
  Return subsets of an an object of class \code{madata} meeting given
  conditions.
}

\arguments{
  \item{x}{An object of class \code{madata}. Read
    \code{\link[maanova]{createData}} for details.}
  \item{arrays}{A vector specifying which arrays to keep or discard.}
  \item{genes}{A vector specifying which genes to keep or discard.}
  \item{\dots}{Ignored at this point.}
}

\value{
  An object of class \code{madata} with specified arrays and genes.
}

\examples{
data(dbldyeswap)
# create data object with replicate
data <- createData(rawdata, n.rep=2)
# take out array 1 and 2
smalldata <- subset(data, arrays=c(1,2))
# take out the all arrays except array 1
idx.array <- 1:data$n.array
smalldata <- subset(data,arrays=(idx.array[-1]))
# take out gene number 1 to 20
smalldata <- subset(data,genes=1:20)
}

\keyword{utilities}

\eof

\author{Hao Wu \email{hao@jax.org} }

\name{transform.madata}
\alias{transform.madata}
\alias{transform.rawdata}

\title{Micro Array experiment data transformation}

\description{
  This is the function to transform the Micro Array experiment data
  based on the given method. 
}

\details{
  The smoothing methods include:
  
  shift -- the calculation of offset is based on the minimum
  sum of absolute deviations (SAD). Each array will have its own offset
  value. The data after shift cannot be smaller than 1.

  glowess -- Intensity-based lowess. This method is to smooth the scatter
  plot of Ratio (R/G) versus Intensity (R*G). The formula in the fitting
  is ratio ~ intensity. 

  rlowess -- Joint lowess. This method is to smooth the scatter plot
  of Ratio versus Intensity and grid locations. It is the joint of
  intensity-based lowess and spatial loess. You have to have the grid
  location for every spot in order to use this method. The formula in
  fitting is ratio ~ intesity + row + col. 

  linlog -- Linear-log transformation.

  linlogshift -- Linear-log shift transformation.
  
  Previously, intensity lowess was called global lowess and joint lowess
  was called regional lowess. So I use "glowess" and "rlowess" in the
  method. Although the method names doesn't make too much sense, I will
  keep them for the reason of backward compatibility.
  
  If you have replicated spots and want to collapse them in
  \code{\link[maanova]{createData}} by providing avgreps=1 or 2, you will
  lose grid information and joint lowess will be unavailable.

  This function works on both \code{rawdata} and \code{madata} objects.
  For \code{rawdata}, the result transformed data will be on the raw
  scale. For \code{madata}, the result transformed data will be on log2
  based scale.

  Note that this function is only working for two-dye array at this
  time. 
}

\usage{
transform.madata(x,method=c("shift","glowess","rlowess","linlog","linlogshift"),
       lolim, uplim, f=0.1, iter=3, degree=1, cg=0.3, cr=0.3, n.bin=10,
       draw=c("screen", "dev", "off"), \dots)
}

\arguments{
  \item{x}{An object of class \code{madata} or \code{rawdata}.}
  \item{method}{The smoothing method.}
  \item{lolim}{Low shift limit. If this argument is missing, the negative
    of the minimum element in the pmt data is used.}
  \item{uplim}{High shift limit. If this argument is missing, the minimum
    element in the pmt data is used. lolim and uplim are applicable only if
    the method is "shift" or "linlogshift".}
  \item{f}{The smoother span. This gives the proportion of points in the
    plot which influence the smooth at each value. Larger values give
    more smoothness. It is equivalent to the "span" parameter in
    \code{\link[modreg]{loess}}.}
  \item{iter}{The number of robustifying iterations which should be
    performed. Using smaller values of iter will make lowess run
    faster.}
  \item{degree}{The degree of the polynomials to be used in loess, up to
    2. This is used when method is "glowess" or "rlowess".}
  \item{cg}{Percentage of genes to be transformed linearly for the green
    channel.}
  \item{cr}{Percentage of genes to be transformed linearly for the red
    channel.}
  \item{n.bin}{Number of bins for calculating the variance after
    linlogShift.}
  \item{draw}{Where to plot the transformation plots. "off" means
    no plot. "screen" means to display the plots on screen then
    x11() (in Unix/Windows) or
    macintosh() (in Mac) will be called inside the function.
    "dev" means to output the plots to the current device. User can use
    this option to output the plot to a file. Default option is
    "screen". }
  \item{\dots}{Ignored at this point.}
}

\section{Value}{
  The return value is an object of class \code{madata} or
  \code{rawdata}. Compared with the input object, the following fields
  are changed:
  \itemize{
    \item Field \code{data} is the transformed data.
    \item Field \code{TransformMethod} will be the transformation method
    applied.
  }
}

\examples{
# load in data
data(dbldyeswap)
# do regional loess on raw data
\dontrun{raw.lowess <- transform(rawdata, method="rlowess")
graphics.off()

# make data object and do normalization on it
# create data object with collapsing replicates
data1<-createData(rawdata, n.rep=2, avgreps=1)
# do shift without displaying the plot
data1.shift <- transform(data1, method="shift", lolim=-50, uplim=50,
         draw="off")
}
# do global lowess and output the plots to a postscript file
\dontrun{postscript(file="glowess.ps")
data1.glowess <- transform(data1, method="glowess", draw="dev")
graphics.off()

# do linear-log
data1.linlog <- transform(data1, method="linlog")
graphics.off()

# do linear-log shift
data1.linlogshift <- transform(data1, method="linlogshift", lolim=-50,
  uplim=50)
graphics.off()

# note that spatial lowess will be unavailable after collapsing
data1.rlowess <- transform(data1, method="rlowess")} # get an error here
}

\references{
  Kerr and Churchill(2001), Statistical design and the analysis of gene
  expression microarrays, \emph{Genetical Research}, \bold{77}:123-128.
  
  Kerr, Martin and Churchill(2000), Analysis of variance for gene expression
  microarray data, \emph{Journal of Computational Biology},
  \bold{7}:819-837.

  Cui, Kerr and Churchill(2002), Data transformations for cDNA
  Microarray data, submitted, find manuscript in www.jax.org/research/churchill.
}


\seealso{
  \code{\link[modreg]{loess}}
}


\keyword{smooth}


\eof
\author{Hao Wu \email{hao@jax.org} }

\name{varplot}
\alias{varplot}

\title{Variance component plot}

\description{
  This function plots the density curve of each variance component of a
  result from \code{\link[maanova]{fitmaanova}}.

  If the input is from fixed model ANOVA, it will plot one curve for
  error variance component. If the input is from mixed model ANOVA, it
  will plot multiple curves, one for a random term (including error). 
}

\usage{
varplot(anovaobj)
}

\arguments{
  \item{anovaobj}{An object of class \code{maanova}.}
}

\examples{
# load in Paigen's data
data(paigen)
# make data object with rep 2
paigen <- createData(paigen.raw, 2)
\dontrun{model.full.mix <- makeModel(data=paigen,
      formula=~Dye+Array+Spot+Strain+Diet+Strain:Diet+Sample,
      random=~Array+Spot+Sample)
anova.full.mix <- fitmaanova(paigen, model.full.mix, method="REML")
varplot(anova.full.mix)}
}

\seealso{
  \code{\link[maanova]{fitmaanova}},
  \code{\link[base]{density}}
}

\keyword{dplot}

\eof
\author{Hao Wu \email{hao@jax.org} }

\name{volcano}
\alias{volcano}

\title{Volcano plot for F test results}

\description{
  This function generates a volcano-like plot given the F test results. 
}

\details{
  This function allows one to visualize the results from the F or T 
  tests. The figure looks like an erupting volcano. There will be one
  plot For F-test result and multiple plots for T-test result, each plot
  crresponds to one T-test. You must have F1 test result in the input
  object in order to do volcano plot. 

  On the plot, the y-axis value is -log10(P-value) for the F1 test.
  The x-axis value is propotional to the fold changes. 
  A horizontal line represents the significance threshold of
  the F1 test. The red dots are the genes selected by the F2
  test (if there's F2 test result). 
  The green dots are the genes selected by the F3
  test (if there's F3 test result).
  The orange dots are the genes
  selected by the Fs test (if there's Fs test result). If there
  is flag information in the data and the user wants to highlight the
  flagged genes, the genes with any bad spots will be circled by a black
  circle.  
}
  
\usage{
volcano(matestobj, threshold=c(0.001,0.05,0.05,0.05),
        method=c("unadj","unadj","unadj","unadj"), title="Volcano Plot",
        highlight.flag=TRUE, onScreen=TRUE)
}

\arguments{
  \item{matestobj}{An object of class \code{matest}.}
  \item{threshold}{A vector of four double values to indicate the
    thresholds for four F tests. The values should be between 0 and 1.
    Note that you need to put four values here even if you don't have
    all four F tests in matestobj.}
  \item{method}{A flag indicating to use which P values to generate the
    plot and select genes. This is a vector with four elements, which
    corresponds to four F tests. Each element should be one of the
    following five selections:
    \itemize{
      \item{"unadj"}{Unadjusted tabulated P values.}
      \item{"nominal"}{Nominal permutation P values.}
      \item{"fwer"}{FWER one-step adjusted P values.}
      \item{"fdr"}{FDR adjusted tabulated P values.}
      \item{"fdrperm"}{FDR adjusted nominal permutation P values.}
    }
    Default value is c("unadj", "unadj", "unadj", "unadj") which means to use
    tabulated P values for all four tests.

    Note that you need to put four values here even if you don't have
    all four F tests in matestobj.}
  \item{title}{Figure title. Default is "Volcano Plot".}
  \item{highlight.flag}{A logical value to indicate whether to highlight
    the genes with bad spots or not.}
  \item{onScreen}{A logical value to represent whether to display the
    plots on screen or not. If TRUE, the figure will be plotted on the
    screen. Otherwise, it will plot the figure on the current device.
    Default is TRUE.}
}

\value{
  For F-test volcano plot, it returns an object which is a list of the
  following four fields: 
  \item{idx.F1}{The significant genes selected by F1 test.}
  \item{idx.F2}{The significant genes selected by F2 test.}
  \item{idx.F3}{The significant genes selected by F3 test.}
  \item{idx.Fs}{The significant genes selected by Fs test.}
  \item{idx.all}{The significant genes selected by all four F tests.}

  For T-test volcano plot, it returns an array of the above object. Each
  element in the array corresponds to one T-test.
}


\examples{
data(paigen)
paigen <- createData(paigen.raw, n.rep=2)

# make model without interaction
model.noint.fix <- makeModel(data=paigen, formula=~Array+Dye+Spot+Strain+Diet)

# F-test strain effect
\dontrun{test.strain.fix <- matest(paigen, model.noint.fix, term="Strain", n.perm=500,
        shuffle.method="resid", test.method=rep(1,4))}
# volcano plot
\dontrun{idx.strain.fix <- volcano(test.strain.fix, title="Strain test - fixed model")}

# T-test all pairwise comparison on strain
\dontrun{C <- matrix(c(1,-1,0,1,0,-1, 0,1,-1), nrow=3, byrow=TRUE)
ttest.strain.fix <- matest(paigen, model.noint.fix, term="Strain",
         Contrast=C, n.perm=500, test.method=rep(1,4))
# volcano plot
volcano(ttest.strain.fix)}
}

\keyword{hplot}

\eof
\author{Hao Wu \email{hao@jax.org} }

\name{write.madata}
\alias{write.madata}

\title{Write Micro Array data to a TAB delimited simple text file}

\description{
  This function is used to write the contents of an object of class
  \code{madata} or \code{rawdata} to a TAB delimited simple text file.
}

\usage{
write.madata <- function(madata, datafile="madata.txt",
          designfile="design.txt")
}

\arguments{
  \item{madata}{The object to be output. It must be an object of class
    \code{madata} or \code{rawdata}.}
  \item{datafile}{The output file name for the data.}
  \item{designfile}{The output file name for the design file.}
}

\examples{
# load in data
data(paigen)
# make data object
paigen <- createData(paigen.raw, 2)
# take out first 6 arrays
smallpaigen <- subset(paigen, array=1:6)
# write to file
\dontrun{write.madata(smallpaigen, datafile="smallpaigen.txt",
      designfile="smallpaigendesign.txt")}
}

\keyword{IO}





\eof
